REBOL [
	Title: "REBOL Mezzanine Functions: Encap Network Setup"
	Version: 2.7.8
	Rights: "Copyright REBOL Technologies 2011. All rights reserved."
	Home: http://www.rebol.com
	Date: 1-Jan-2011

	; You are free to use, modify, and distribute this file as long as the
	; above header, copyright, and this entire comment remains intact.
	; This software is provided "as is" without warranties of any kind.
	; In no event shall REBOL Technologies or source contributors be liable
	; for any damages of any kind, even if advised of the possibility of such
	; damage. See license for more information.

	; Please help us to improve this software by contributing changes and
	; fixes. See http://www.rebol.com/support.html for details.
	; You are free to use, modify, and distribute this software with any
	; REBOL Technologies products as long as the above header, copyright,
	; and this comment remain intact. This software is provided "as is"
	; and without warranties of any kind. In no event shall the owners or
	; contributors be liable for any damages of any kind, even if advised
	; of the possibility of such damage. See license for more information.

	; Please help us to improve this software by contributing changes and
	; fixes via http://www.rebol.com/feedback.html - Thanks!
]

netfile: %network.txt

load-network: func [
	/local net-txt name email smtp pop proxy-host proxy-port proxy-type] [
	if exists? system/options/home/:netfile [
		net-txt: load/all system/options/home/:netfile
		set [name email smtp pop proxy-host proxy-port proxy-type] none
		parse net-txt [some [
				'user-name set name [word! | string!]
				| 'email set email email!
				| 'smtp-host set smtp [word! | string!]
				| 'pop-host set pop [word! | string!]
				| 'proxy-host set proxy-host [word! | string!]
				| 'proxy-port set proxy-port [integer!]
				| 'proxy-type set proxy-type [word! | string!]
				| any-type! ; catch all other junk
			]
		]
		set-net reduce [email smtp pop proxy-host proxy-port proxy-type]
		if name = 'none [name: none]
		system/user/name: name
		return true
	]
	false ; failed to load file
]

save-network: func [/local schemes proxy net] [
	schemes: get in system 'schemes
	proxy: get in system/schemes/default 'proxy
	net: open/new system/options/home/:netfile
	foreach [name value] reduce ['user-name system/user/name 'email system/user/email
								 'smtp-host schemes/default/host 'pop-host schemes/pop/host
								 'proxy-host proxy/host 'proxy-port proxy/port-id 'proxy-type proxy/type] [
		repend net [:name tab mold value newline]
	]
	close net
]

ask-net: func [
	"Ask user for network settings."
	/local ask-it questions
][
	system/user/email:
	system/schemes/default/host:
	system/schemes/default/proxy/host:
	system/schemes/default/proxy/port-id:
	system/schemes/default/proxy/type: none

	;-- Use Query Dialect:
	questions: [
		{
		Some network functions, such as sending email or
		using anonymous FTP, require you to provide an email
		address.  (Or, you just press ENTER to skip it.)
		
		Email address?} [
			either empty? answer [questions: skip questions 2][
				system/user/email: to-email answer]
		]
		{
		To send email you also need to provide the name of
		your email server (such as mail.domain.com). If you
		don't know it, check the configuration of your email
		program or ask your network administrator.
		
		Email server name?} [system/schemes/default/host: answer]
		{
		REBOL can connect directly to the Internet or through
		a firewall via a proxy server.  If it's a direct
		connection, just press ENTER.  To set the proxy
		settings, you will need the proxy server's host name,
		TCP/IP port number, and proxy type.  Ask your network
		administrator if necessary.

		Do you require a proxy server?}
		{
		What is the host name of your proxy server? }
			[system/schemes/default/proxy/host: answer]
		{
		What is the TCP/IP port number used to connect to
		your proxy server?} 
			[system/schemes/default/proxy/port-id: to-integer answer]
		{
		Type the number of the proxy type you are using:
			1 - SOCKS version 5
			2 - SOCKS version 4
			3 - GENERIC (CERN)

		Which number?} [
			if none? system/schemes/default/proxy/type:
				pick [socks socks4 generic] to-integer answer
					[barf-here]
		]
		{
		Would you like to verify your network settings by
		sending a test email message to REBOL.com? If it
		fails with an error, your settings are not correct
		or your system is not connected to the Internet.

		Send a test message?} [
			either find/match answer "y" [
				print "Sending message now..."
				send luke@rebol.com "Testing!"
				print "Message was sent."
			][
				print "Okay. You can try email out later."
			]
		]
	]

	ask-it: [answer: ask append insert trim questions/1 newline " "]
	until [
		do ask-it
		tail? either block? questions/2 [
			while [error? try questions/2] ask-it
			questions: skip questions 2
		][
			questions: either find/match answer "y" [next questions][
				tail questions]
		]
	]
	system/schemes/smtp/host: system/schemes/default/host
]

set-network: func [] [
	if all [
		0 = (system/options/boot-flags and to-integer #4000)
		not load-network
	] [
		print ""
		print trim {
			PLEASE NOTE:
			Your network preferences file (network.txt) was not found.
			For your network functions to work properly, you
			need to provide network setup information.
		}
		if confirm "Would you like to setup networking now? " [
			ask-net
			save-network
			print "REBOL is now ready for network operation."
		]
	]
]

