REBOL [
	Title:  "REBOL Protocols: POP"
	Author: ["Carl Sassenrath" "Holger Kruse"]
	Rights: "Copyright REBOL Technologies 1997-2002"
	; You are free to use, modify, and distribute this software with any
	; REBOL Technologies products as long as the above header, copyright,
	; and this comment remain intact. This software is provided "as is"
	; and without warranties of any kind. In no event shall the owners or
	; contributors be liable for any damages of any kind, even if advised
	; of the possibility of such damage. See license for more information.

	; Please help us to improve this software by contributing changes and
	; fixes via http://www.rebol.com/feedback.html - Thanks!
]

make Root-Protocol [
	{Communicate with POP.  This protocol is block oriented not
	string oriented.}
	
	port-flags: system/standard/port-flags/pass-thru

	post-open-check:  [
		none "+OK"
	]
	user-pass-check: [ ; port is bound to confirm frame
;		["USER" either port/proxy/host [
;			rejoin [port/user "#" port/proxy/host]]]
		["USER" port/user] "+OK"
		["PASS" port/pass] "+OK"
	]
	close-check: ["QUIT" "+OK"]
	write-check: [none   "+OK"]
	stat-check:  ["STAT" "+OK"]
	list-check:  ["LIST" "+OK"]

	open: func [port /local total greeting timestamp][
		open-proto port
		greeting: net-utils/confirm port/sub-port post-open-check
		if any [
			port/algorithm <> 'apop
			not parse greeting [to "<" copy timestamp thru ">" to end]
			error? catch [
				net-utils/confirm port/sub-port reduce [
					reform ["APOP" port/user lowercase enbase/base checksum/method
					 rejoin [timestamp port/pass] 'md5 16] "+OK"
				]
			]
		] [
			net-utils/confirm port/sub-port user-pass-check
		]
		port/state/tail: second total: load net-utils/confirm port/sub-port stat-check
		port/locals: make object! [
			total-size: third total
			net-utils/confirm port/sub-port list-check 
			sizes: load read-til-dot port make string! 100 
			msg-nums: make block! port/state/tail
			repeat n port/state/tail [append msg-nums n] ; lookaside index
		]
		port/state/index: 0   ; a zero based index
	]

	read-til-dot: func [port buf][
		while ["." <> line: system/words/pick port/sub-port 1] [
			insert insert tail buf either #"." = system/words/pick line 1 [next line][line] newline
		] 
		buf
	]

	read-message: func [
		"Read a message from the POP server"
		port 
		n [integer!]
		/local buf line
	][
		insert port/sub-port reform [
			"RETR" system/words/pick port/locals/msg-nums port/state/index + n]
		net-utils/confirm port/sub-port write-check
		read-til-dot port buf: make string! 1024  ; guess at size
	]
	
	pick: func [
		"Read the Nth message from the POP port"
		port
	][
		read-message port 1
	]

	copy: func [
		"Copy a set of messages into a block"
		port
		/local msgs n
	][
		msgs: make block! port/state/num
		repeat n port/state/num [
			append msgs read-message port n
		]
		msgs
	]

	remove: func [
		"Remove the current message"
		port
	][
		while [ port/state/num > 0 ][
			insert port/sub-port reform [
				"DELE" system/words/pick port/locals/msg-nums port/state/index + 1]
			net-utils/confirm port/sub-port write-check
			system/words/remove at port/locals/msg-nums port/state/index + 1
			port/state/tail: port/state/tail - 1
			port/state/num: port/state/num - 1
		]
		port
	]

	net-utils/net-install POP self 110
]
