REBOL [
	Title: "REBOL/View Desktop - File Initialization"
	Version: 1.0.0
	Author: "Carl Sassenrath"
	Rights: "Copyright REBOL Technologies 1999-2005. All rights reserved."
	; You are free to use, modify, and distribute this software with any
	; REBOL Technologies products as long as the above header, copyright,
	; and this comment remain intact. This software is provided "as is"
	; and without warranties of any kind. In no event shall the owners or
	; contributors be liable for any damages of any kind, even if advised
	; of the possibility of such damage. See license for more information.

	; Please help us to improve this software by contributing changes and
	; fixes via http://www.rebol.com/feedback.html - Thanks!
]

init-desktop-files: has [paths path files] [
	; Create default desktop files if they are missing:

	this-path: none
	history-file: view-root/desktop/history.r

	paths: [
		%desktop/
		%local/
		%desktop/icons/
		%desktop/skins/
		%desktop/sounds/
		%desktop/tools/
	]

	foreach path paths [if not exists? view-root/:path [attempt [make-dir/deep view-root/:path]]]

	if not exists? path: view-root/desktop/filetypes.r [
		write path join {REBOL [Title: "File Types"]^/} mold/only suffix-map
	]

	files: [
		%desktop/bookmarks.r {
			REBOL [Title: "Bookmarks" Type: 'index]

			folder "REBOL" http://www.rebol.com/index.r
			info "REBOL.com primary REBOL/View reb-site"
			folder "Public" http://www.rebol.com/view/public.r
			info "Public sites, links, and programs"
			folder "Local" %local/index.r
			info "Local links and files"
			file "Console" console icon console
			info "Open the REBOL console"
		}
		%desktop/services.r {
			REBOL [Title: "Services" Type: 'index]

			service "Goto" goto
			service "Help" help
			service "Quit" quit
		}
		%local/index.r {
			REBOL [Title: "Local Index" Type: 'index]

			title "Local Files"

			file "Info" %info.txt
		}
		%local/info.txt {
			Local scripts can be placed in this folder. To do so, edit
			your local/index.r file to include the filenames for the
			files that you want to include. You can right click on the
			local folder icon to edit or reload it.
		}
	]
	foreach [file text] files [
		if not exists? path: view-root/:file [write path trim/auto text]
	]
	if not exists? history-file [
		save history-file [
			http://www.rebol.com/index.r
			http://www.rebol.com/index.html
		]
	]
]

